#!/bin/bash
#
#-------------------------------------------------------#
# This file is Juju managed - do not make local changes #
#-------------------------------------------------------#
#
# Copyright 2014 Canonical Ltd.
#
# Check when the last mirror update was and warn if too old

set -u
set -e

if [ $# -ne 2 ]; then
    echo "Usage: check-updates.sh [name] [logfile]"
    echo "Example: check-updates.sh archive.ubuntu.com /var/log/update.log"
    exit 1
fi

NAME=$1
LOGFILE=$2

if [ ! -r ${LOGFILE} ]; then
    echo "CRITICAL Cannot determine ${NAME} update status [${LOGFILE} does not exist or is not readable]"
    exit 2
fi

now=$(date +"%s")
file_mtime=$(stat --format="%Y" ${LOGFILE})

file_age=$(($now - $file_mtime))

function days {
    echo $(( $1 * 24 * 3600 ))
}

case $NAME in
    images.maas.io)
	crit_age=$(days 7)
	;;
    old-releases.ubuntu.com)
	crit_age=$(days 365)
	;;
    *)
	crit_age=$(days 2)
	;;
esac

warn_age=$(( crit_age / 2 ))

if [ ${file_age} -gt $crit_age ]; then
    echo "CRITICAL Mirror ${NAME} [Has not updated for at least $(( $crit_age / 3600 )) hours]"
    exit 2
elif [ ${file_age} -gt $warn_age ]; then
    echo "WARNING Mirror ${NAME} [Has not updated for at least $(( $warn_age / 3600 )) hours]"
    exit 1
fi

echo "OK Mirror ${NAME} [Has updated within the last $(( warn_age / 3600 )) hours]"
exit 0
