import os
import pytest
import unittest

from Cheetah.Template import Template

TEMPLATE = 'apache-linuxcontainers.tmpl'

THIRDPARTY_SEARCH_LIST = {
    'addresses': ['*'],
    'name': 'lxd.example.net',
    'aliases': ['uk.lxd.example.net', 'us.lxd.example.net'],
    'ports': [80, 443],
}

LINUXCONTAINERS_SEARCH_LIST = {
    'addresses': ['91.189.88.247',  '[2001:67c:1360:8001::33]'],
    'name': 'images.linuxcontainers.org',
    'aliases': ['uk.images.linuxcontainers.org', 'us.images.linuxcontainers.org'],
    'ports': [80, 443, 8443],
}


class TestLinuxcontainers(unittest.TestCase):
    def setUp(self):
        self.addTypeEqualityFunc(str, self.assertMultiLineEqual)
        self.maxDiff = None
        self.testdata_dir = os.path.join(os.path.dirname(__file__), 'testdata', 'linuxcontainers')

    def _template_compare(self, template, search_list, wanted_file):
        template_file = os.path.join(os.getcwd(), template)
        template = Template(file=template_file, searchList=search_list)
        wanted = open(wanted_file).read()
        self.assertEqual(str(template), wanted)

    # Cheetah warns about using the Python version of NameMapper, so
    # we ignore it here.  Matching more closely by the message doesn't
    # seem to work, probably because it begins with a newline and
    # Python's warnings matching code anchors the message regexp.
    @pytest.mark.filterwarnings("ignore::UserWarning:Cheetah")
    def test_template_linuxcontainers(self):
        self._template_compare(
            os.path.join(os.getcwd(), 'templates', TEMPLATE),
            LINUXCONTAINERS_SEARCH_LIST,
            os.path.join(self.testdata_dir, 'linuxcontainers.txt'))

    # Cheetah warns about using the Python version of NameMapper, so
    # we ignore it here.  Matching more closely by the message doesn't
    # seem to work, probably because it begins with a newline and
    # Python's warnings matching code anchors the message regexp.
    @pytest.mark.filterwarnings("ignore::UserWarning:Cheetah")
    def test_template_thirdparty(self):
        self._template_compare(
            os.path.join(os.getcwd(), 'templates', TEMPLATE),
            THIRDPARTY_SEARCH_LIST,
            os.path.join(self.testdata_dir, 'thirdparty.txt'))
