import yaml


# The Config class fails if config items aren't present, so it's
# simplest to just read config.yaml and mock hookenv.config().
def read_config_yaml():
    """Read config.yaml and return a dict keyed by setting, with their
    defaults as values, stringified a la config-get."""

    with open('config.yaml') as config_yaml:
        config = yaml.safe_load(config_yaml)
    return {k: str(v['default']) for k, v in config['options'].items() if 'default' in v}


# Used to mock hookenv.config().
class CallableDict(dict):
    """Wrapper for dict type: d(x) <==> d[x].  Intended as a drop-in
    replacement (or mock) for functions such as config() while
    allowing responses to be easily configured.  Example use, which
    assumes that something() is imported from somelib, and somelib did
    "from charmhelpers.core.hookenv import config":

        from somelib import something

        class TestSomething(unittest.TestCase):
            @patch('somelib.config')
            def test_something(self, _config):
                _config.side_effect = CallableDict({'key': 'value'})
                self.assertTrue(something())

    """

    def __call__(self, *args, **kwargs):
        return self.__getitem__(*args, **kwargs)
